@@ -16,7 +16,7 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *    $Header: /cvsroot/jnettop/jnettop/jutil.h,v 1.5 2005/07/01 11:25:32 merunka Exp $
+ *    $Header: /cvsroot/jnettop/jnettop/jutil.h,v 1.7 2006/04/12 07:47:01 merunka Exp $
  *
  */
 
@@ -30,6 +30,8 @@ int jutil_IsHostAggregation(int af, const jbase_mutableaddress *addr);
 const char * jutil_Address2String(int af, const jbase_mutableaddress *src, char *dst, size_t cnt);
 gboolean jutil_String2Address(const char *address, jbase_mutableaddress *dest, int *af);
 guint jutil_ParseAggregation(const char *agg);
+void jutil_formatNumber(guint32 n, gboolean onoffPackets, gchar *buf, int len);
 void memand(char *buf1, const char *buf2, int length);
+gboolean jutil_IsInNetwork(const jbase_mutableaddress *address, int address_af, const jbase_mutableaddress *network, const jbase_mutableaddress *netmask, int network_af);
 
 #endif
